import java.sql.*;
import java.util.Properties;

class Test {

    static String url           = "jdbc:easysoft://demo.easysoft.com/pubs";
    static String query         = "tables"; 
    static String user          = "demo";
    static String password      = "easysoft";
    static String logonuser     = "";
    static String logonpassword = "";
    static int resultSetLimit   = 50;


    public static  void usage() {
	System.out.println("Usage: \n" + 
			   "  Test -url      		<Easysoft JDBC url>\n" +
			   "       -user     		<user name>\n" +		
			   "       -password 		<passrord>\n" +		
			   "       -logonuser   	<server access user name>\n" +		
			   "       -logonpassword 	<server access password>\n" +		
			   "       -sql      		<SQL query or the string \"tables\">\n" +
			   "       -l        		<limit on the number of records retrieved>\n"
			   );
    }
    public static void main (String args[]) {
	
		
	if (args.length>0) {
	    for (int i = 0; i < args.length; i++) {
		if (args[i].equals("")){ 
		    // skip 
		    if (i + 1 < args.length) {
			i++;
		    }
		} else if (args[i].equals("-url")) {
		    if (i + 1 < args.length) {
			i++;
			url = args[i];
		    }
		} else if (args[i].equals("-user")) {
		    if (i + 1 < args.length) {
			i++;
			user = args[i];
		    }
		} else if (args[i].equals("-password")) {
		    if (i + 1 < args.length) {
			i++;
			password = args[i];
		    }
		} else if (args[i].equals("-logonuser")) {
		    if (i + 1 < args.length) {
			i++;
			logonuser = args[i];
		    }
		} else if (args[i].equals("-logonpassword")) {
		    if (i + 1 < args.length) {
			i++;
			logonpassword = args[i];
		    }
		} else if (args[i].equals("-sql")) {
		    if (i + 1 < args.length) {
			i++;
			query = args[i];
		    }
		}   else if (args[i].equals("-l")) {
		    if (i + 1 < args.length) {
			i++;
			resultSetLimit = new  Integer(args[i]).intValue();
		    }  
		} else if (args[i].equals("-h")) {
		    usage();
		    System.exit(0);
		}
	    }
	}
	else {
	    usage();
	    System.exit(0);
	}
	try {
	    // Load the Easysoft JDBC=ODBC Bridge Driver
	    Class.forName ("easysoft.sql.jobDriver");

		Connection con;

	    // Attempt to connect to a driver.  Each one
	    // of the registered drivers will be loaded until
	    // one is found that can process this URL
		// If additional connection properties need to be used, 
		// create a Properties object to pass them into the connect
		if ( logonuser.length() > 0 || logonpassword.length() > 0 ) {
			Properties p = new Properties();

			p.put( "user", user );
			p.put( "password", password );

			if ( logonuser.length() > 0 ) {
				p.put( "logonuser", logonuser );
			}

			if ( logonpassword.length() > 0 ) {
				p.put( "logonpassword", logonpassword );
			}

	    	con = DriverManager.getConnection (url, p );
		}
		else {
	    	con = DriverManager.getConnection (url,
							  user,
							  password );
		}

	    // If we were unable to connect, an exception
	    // would have been thrown.  So, if we get here,
	    // we are successfully connected to the URL

	    // Check for, and display and warnings generated
	    // by the connect.
	    checkForWarning (con.getWarnings ());

	    // Get the DatabaseMetaData object and display
	    // some information about the connection
	    DatabaseMetaData dmd = con.getMetaData ();
            String info =
		"JDBC Driver Name:      : " + dmd.getDriverName() + "\n" +
		"JDBC Driver Version:           "
		+ dmd.getDriverVersion() + "\n" +
		"URL:                    " + dmd.getURL() + "\n" +
		"User Name:               " + dmd.getUserName() + "\n" +
		"Database Product Name:    " 
		+ dmd.getDatabaseProductName()  + "\n" +
		"Database Product Version: "
		+ dmd.getDatabaseProductVersion()  + "\n";	 
	    System.out.println(info);
	    System.out.println("");

	    // Create a Statement object so we can submit
	    // SQL statements to the driver
	    Statement stmt = con.createStatement ();

	    // Submit a query, creating a ResultSet object
	    ResultSet rs = stmt.executeQuery (query);

	    // Display all columns and rows from the result set
	    showResultSet (rs);

	    // Close the result set
	    rs.close();

	    // Close the statement
	    stmt.close();

	    // Close the connection
	    con.close();

	    System.exit(1);
	}
	catch (SQLException ex) {

	    // A SQLException was generated.  Catch it and
	    // display the error information.  Note that there
	    // could be multiple error objects chained
	    // together
	    System.out.println ("\n*** SQLException caught ***\n");

	    while (ex != null) {
		System.out.println ("SQLState: " +
				    ex.getSQLState ());
		System.out.println ("Message:  " +
				    ex.getMessage ());
		System.out.println ("Vendor:   " +
				    ex.getErrorCode ());
		ex = ex.getNextException ();
		System.out.println ("");
	    }
	}
	catch (java.lang.Exception ex) {

	    // Got some other type of exception.  Dump it.
	    ex.printStackTrace ();
	}
    }

    //-------------------------------------------------------------------
    // checkForWarning
    // Checks for and displays warnings.  Returns true if a warning
    // existed
    //-------------------------------------------------------------------

    private static boolean checkForWarning (SQLWarning warn)
	throws SQLException
    {
	boolean rc = false;

	// If a SQLWarning object was given, display the
	// warning messages.  Note that there could be
	// multiple warnings chained together
	if (warn != null) {
	    System.out.println ("\n *** Warning ***\n");
	    rc = true;
	    while (warn != null) {
		System.out.println ("SQLState: " +
				    warn.getSQLState ());
		System.out.println ("Message:  " +
				    warn.getMessage ());
		System.out.println ("Vendor:   " +
				    warn.getErrorCode ());
		System.out.println ("");
		warn = warn.getNextWarning ();
	    }
	}
	return rc;
    }

    //-------------------------------------------------------------------
    // showResultSet
    // Displays all columns and rows in the given result set
    //-------------------------------------------------------------------

    private static void showResultSet (ResultSet rs)
	throws SQLException
    {

	// Get the ResultSetMetaData. 
	ResultSetMetaData rsmd = rs.getMetaData ();

	// Get the number of columns in the result set
	int numCols = rsmd.getColumnCount ();

	// Display column headings
	for (int i=1; i<=numCols; i++) {
	    if (i > 1) System.out.print(",");
	    System.out.print(rsmd.getColumnLabel(i));
	}
	System.out.println("");
		
	// Display data, fetching until end of the result set or
	// resultSetLimit is not reached
	int rowCount = 0;
	while (rs.next () && rowCount < resultSetLimit) {

	    // Loop through each column, getting the
	    // column data and displaying
	    rowCount++;
	    for (int i=1; i<=numCols; i++) {
		if (i > 1) System.out.print(",");
		System.out.print(rs.getString(i));
	    }
	    System.out.println("");
	}
    }
}








